main

Function main 

pub fn main(args: &[String]) -> ExitCode
Runs recall-server admin, given the arguments after admin.

Exits 0 on success, including a dry run and a change with nothing to do; 1 when a command is refused or fails, having changed nothing; 2 for a usage error; 3 when the change committed but the check after it found something the owner has to act on.