pub enum AddedCredential {
Added,
NotFirst,
Duplicate,
Code(BootstrapCode),
}Expand description
What storing a passkey came to.
Variants
Added
Stored.
NotFirst
Only the first passkey may be stored this way, and there is one already.
Duplicate
A passkey with that credential id is stored already.
Code(BootstrapCode)
The bootstrap code is not the one outstanding, or has expired.