pub enum Inserted {
Done(Box<Device>),
NameTaken,
KeyFull,
}Expand description
What storing a device came to.
Variants
Done(Box<Device>)
Stored. Boxed: the refusals are small, and a device is not.
NameTaken
An unrevoked device already has that name.
KeyFull
Its authkey already has as many unrevoked devices as it may.