pub fn issue(store: &Store, now: OffsetDateTime) -> Result<BootstrapCode>Expand description
Makes a new code the only one, until TTL after now, with the
server’s bootstrap_code leaf, which says until when and never the
code.
pub fn issue(store: &Store, now: OffsetDateTime) -> Result<BootstrapCode>Makes a new code the only one, until TTL after now, with the
server’s bootstrap_code leaf, which says until when and never the
code.